#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ELLPE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ELLPE_HPP_INCLUDED

#include <nt2/elliptic/include/functions/scalar/ellpe.hpp>

#endif
